## Sid Meier's Civilization 4
## Copyright Firaxis Games 2005
## 
## CvEventManager
## This class is passed an argsList from CvAppInterface.onEvent
## The argsList can contain anything from mouse location to key info
## The EVENTLIST that are being notified can be found

from CvPythonExtensions import *

import CvEventManager
import CvUtil
import CvScreensInterface
import CvDebugTools
import CvWBPopups
import PyHelpers
import Popup as PyPopup
import CvCameraControls
import CvTopCivs
import sys
import CvWorldBuilderScreen
import CvAdvisorUtils
import CvTechChooser

gc = CyGlobalContext()

class sEventManager(CvEventManager.CvEventManager):

	def onGameStart(self, argsList):
		'Called at the start of the game'
		if gc.getGame().getStartEra() == gc.getDefineINT("STANDARD_ERA"):
			for k in range(gc.getNumUnitClassInfos()):
				if gc.getUnitInfo(gc.getInfoTypeForString("UNIT_SETTLER")).getUnitClassType() == k:
					iSettler = k
				elif gc.getUnitInfo(gc.getInfoTypeForString("UNIT_WARRIOR")).getUnitClassType() == k:
					iWarrior = k
				elif gc.getUnitInfo(gc.getInfoTypeForString("UNIT_SCOUT")).getUnitClassType() == k:
					iScout = k
			for iPlayer in range(gc.getMAX_PLAYERS()):
				player = gc.getPlayer(iPlayer)
				plot = -1
				bIsScout = False
				bKilledSettler = False
				iNumSettlers = 0
				if player.isAlive():
					for i in range(player.getNumUnits()):
						if player.getUnit(i).getUnitClassType() == gc.getUnitInfo(gc.getCivilizationInfo(iPlayer).getCivilizationUnits(iSettler)).getUnitClassType():
							plot = player.getUnit(i).plot()
							iNumSettlers = iNumSettlers + 1
							bKilledSettler = True
							player.getUnit(i).kill(True, iPlayer)
						elif player.getUnit(i).getUnitClassType() == gc.getUnitInfo(gc.getCivilizationInfo(iPlayer).getCivilizationUnits(iScout)).getUnitClassType():
							bIsScout = True
					if bIsScout == False and bKilledSettler == True:
						player.initUnit(gc.getCivilizationInfo(iPlayer).getCivilizationUnits(iSettler), plot.getX(), plot.getY(), UnitAITypes.NO_UNITAI)
						for ii in range(iNumSettlers - 1):
							if player.isHuman():
								placePlot = self.getPlacementPlot(plot)
							else:
								placePlot = plot
							player.initUnit(gc.getCivilizationInfo(iPlayer).getCivilizationUnits(iWarrior), placePlot.getX(), placePlot.getY(), UnitAITypes.NO_UNITAI)
					elif bIsScout == True and bKilledSettler == True:
						player.initUnit(gc.getCivilizationInfo(iPlayer).getCivilizationUnits(iSettler), plot.getX(), plot.getY(), UnitAITypes.NO_UNITAI)




	def getPlacementPlot(self, plot):

		plotList = list()
		plotList.append(	CyMap().plot(plot.getX()-2,	plot.getY()-2	))
		plotList.append(	CyMap().plot(plot.getX()-2,	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX()-2,	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX()-2,	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX()-2,	plot.getY()+2	))
		plotList.append(	CyMap().plot(plot.getX()-1,	plot.getY()-2	))
		plotList.append(	CyMap().plot(plot.getX()-1,	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX()-1,	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX()-1,	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX()-1,	plot.getY()+2	))
		plotList.append(	CyMap().plot(plot.getX(),	plot.getY()-2	))
		plotList.append(	CyMap().plot(plot.getX(),	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX(),	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX(),	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX(),	plot.getY()+2	))
		plotList.append(	CyMap().plot(plot.getX()+1,	plot.getY()-2	))
		plotList.append(	CyMap().plot(plot.getX()+1,	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX()+1,	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX()+1,	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX()+1,	plot.getY()+2	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()-2	))	
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()+2	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()-2	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()-1	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()+1	))
		plotList.append(	CyMap().plot(plot.getX()+2,	plot.getY()+2	))


		for iPlot in plotList:				#this loop has a 2 in 5 chance of return a good plot
			if iPlot.isWater() or iPlot.getFeatureType() is CvUtil.findInfoTypeNum(gc.getFeatureInfo, gc.getNumFeatureInfos(), 'FEATURE_ICE'):
				pass
			elif CyGame().getSorenRandNum(99, "Zebra9") > 60:
				return iPlot
		for iPlot in plotList:				#this loop will return the first good plot	 : :	 this loop makes sure that a good plot is returned
			if iPlot.isWater() or iPlot.getFeatureType() is CvUtil.findInfoTypeNum(gc.getFeatureInfo, gc.getNumFeatureInfos(), 'FEATURE_ICE'):
				pass
			else:
				return iPlot

		return plot